Class: Keyword
- Inherits:
-
Object
- Object
- Keyword
- Defined in:
- lib/diml/elements/keyword.rb
Defined Under Namespace
Modules: ClassMethods
Instance Attribute Summary collapse
-
#content ⇒ Object
readonly
Returns the value of attribute content.
Instance Method Summary collapse
-
#initialize(content) ⇒ Keyword
constructor
A new instance of Keyword.
-
#virtual? ⇒ Boolean
Returns whether or not the keyword is intended to be a virtual or concrete element By default keywords should be non-virtual.
Constructor Details
#initialize(content) ⇒ Keyword
Returns a new instance of Keyword.
11 12 13 |
# File 'lib/diml/elements/keyword.rb', line 11 def initialize(content) @content = content end |
Instance Attribute Details
#content ⇒ Object (readonly)
Returns the value of attribute content.
9 10 11 |
# File 'lib/diml/elements/keyword.rb', line 9 def content @content end |
Instance Method Details
#virtual? ⇒ Boolean
Returns whether or not the keyword is intended to be a virtual or concrete element By default keywords should be non-virtual
17 18 19 |
# File 'lib/diml/elements/keyword.rb', line 17 def virtual? false end |